@@ -21,10 +21,11 @@
 
 
 
+//! internal use only; subject to removal
 template<typename T>
 inline
 std::ostream&
-arma_cout_stream(std::ostream* user_stream)
+internal_cout_stream(std::ostream* user_stream)
   {
   static std::ostream* cout_stream = &(ARMA_COUT_STREAM);
   
@@ -35,10 +36,11 @@ arma_cout_stream(std::ostream* user_stream)
 
 
 
+//! internal use only; subject to removal
 template<typename T>
 inline
 std::ostream&
-arma_cerr_stream(std::ostream* user_stream)
+internal_cerr_stream(std::ostream* user_stream)
   {
   static std::ostream* cerr_stream = &(ARMA_CERR_STREAM);
   
@@ -49,20 +51,44 @@ arma_cerr_stream(std::ostream* user_stream)
 
 
 
+template<typename T>
+arma_deprecated
 inline
-void
-set_cout_stream(std::ostream& user_stream)
+std::ostream&
+arma_cout_stream(std::ostream* user_stream)
   {
-  arma_cout_stream<char>(&user_stream);
+  return internal_cout_stream<T>(user_stream);
   }
 
 
 
+template<typename T>
+arma_deprecated
+inline
+std::ostream&
+arma_cerr_stream(std::ostream* user_stream)
+  {
+  return internal_cerr_stream<T>(user_stream);
+  }
+
+
+
+arma_deprecated
+inline
+void
+set_cout_stream(std::ostream& user_stream)
+  {
+  internal_cout_stream<char>(&user_stream);
+  }
+
+
+
+arma_deprecated
 inline
 void
 set_cerr_stream(std::ostream& user_stream)
   {
-  arma_cerr_stream<char>(&user_stream);
+  internal_cerr_stream<char>(&user_stream);
   }
 
 
@@ -71,7 +97,7 @@ inline
 std::ostream&
 get_cout_stream()
   {
-  return arma_cout_stream<char>(nullptr);
+  return internal_cout_stream<char>(nullptr);
   }
 
 
@@ -80,36 +106,36 @@ inline
 std::ostream&
 get_cerr_stream()
   {
-  return arma_cerr_stream<char>(nullptr);
+  return internal_cerr_stream<char>(nullptr);
   }
 
 
 
 //! do not use this function - it's deprecated and will be removed
-inline
 arma_deprecated
+inline
 void
 set_stream_err1(std::ostream& user_stream)
   {
-  set_cerr_stream(user_stream);
+  internal_cerr_stream<char>(&user_stream);
   }
 
 
 
 //! do not use this function - it's deprecated and will be removed
-inline
 arma_deprecated
+inline
 void
 set_stream_err2(std::ostream& user_stream)
   {
-  set_cerr_stream(user_stream);
+  internal_cerr_stream<char>(&user_stream);
   }
 
 
 
 //! do not use this function - it's deprecated and will be removed
-inline
 arma_deprecated
+inline
 std::ostream&
 get_stream_err1()
   {
@@ -119,8 +145,8 @@ get_stream_err1()
 
 
 //! do not use this function - it's deprecated and will be removed
-inline
 arma_deprecated
+inline
 std::ostream&
 get_stream_err2()
   {
@@ -389,12 +415,6 @@ arma_warn(const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4)
 // arma_warn_level
 
 
-#if defined(ARMA_EXTRA_DEBUG)
-  #undef  ARMA_WARN_LEVEL
-  #define ARMA_WARN_LEVEL 3
-#endif
-
-
 template<typename T1>
 inline
 void
@@ -454,6 +474,16 @@ arma_check(const bool state, const T1& x)
   }
 
 
+template<typename Functor>
+arma_hot
+inline
+void
+arma_check(const bool state, const char* x, const Functor& fn)
+  {
+  if(state)  { fn(); arma_stop_logic_error(x); }
+  }
+
+
 arma_hot
 inline
 void
@@ -463,6 +493,16 @@ arma_check(const bool state, const char* x, const char* y)
   }
 
 
+template<typename Functor>
+arma_hot
+inline
+void
+arma_check(const bool state, const char* x, const char* y, const Functor& fn)
+  {
+  if(state)  { fn(); arma_stop_logic_error(x,y); }
+  }
+
+
 template<typename T1>
 arma_hot
 inline
@@ -1421,6 +1461,7 @@ arma_assert_atlas_size(const T1& A, const T2& B)
         out << "@ arma_config::wrapper          = " << arma_config::wrapper          << '\n';
         out << "@ arma_config::cxx14            = " << arma_config::cxx14            << '\n';
         out << "@ arma_config::cxx17            = " << arma_config::cxx17            << '\n';
+        out << "@ arma_config::cxx20            = " << arma_config::cxx20            << '\n';
         out << "@ arma_config::std_mutex        = " << arma_config::std_mutex        << '\n';
         out << "@ arma_config::posix            = " << arma_config::posix            << '\n';
         out << "@ arma_config::openmp           = " << arma_config::openmp           << '\n';
