@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -86,30 +88,47 @@ class field
   template<typename oT2>
   inline void copy_size(const field<oT2>& x);
   
-  arma_inline       oT& operator[](const uword i);
-  arma_inline const oT& operator[](const uword i) const;
+  arma_inline arma_warn_unused       oT& operator[](const uword i);
+  arma_inline arma_warn_unused const oT& operator[](const uword i) const;
   
-  arma_inline       oT&         at(const uword i);
-  arma_inline const oT&         at(const uword i) const;
+  arma_inline arma_warn_unused       oT&         at(const uword i);
+  arma_inline arma_warn_unused const oT&         at(const uword i) const;
   
-  arma_inline       oT& operator()(const uword i);
-  arma_inline const oT& operator()(const uword i) const;
+  arma_inline arma_warn_unused       oT& operator()(const uword i);
+  arma_inline arma_warn_unused const oT& operator()(const uword i) const;
   
-  arma_inline       oT&         at(const uword row, const uword col);
-  arma_inline const oT&         at(const uword row, const uword col) const;
+  #if defined(__cpp_multidimensional_subscript)
+  arma_inline arma_warn_unused       oT& operator[](const uword row, const uword col);
+  arma_inline arma_warn_unused const oT& operator[](const uword row, const uword col) const;
+  #endif
+  
+  arma_inline arma_warn_unused       oT&         at(const uword row, const uword col);
+  arma_inline arma_warn_unused const oT&         at(const uword row, const uword col) const;
+  
+  #if defined(__cpp_multidimensional_subscript)
+  arma_inline arma_warn_unused       oT& operator[](const uword row, const uword col, const uword slice);
+  arma_inline arma_warn_unused const oT& operator[](const uword row, const uword col, const uword slice) const;
+  #endif
+  
+  arma_inline arma_warn_unused       oT&         at(const uword row, const uword col, const uword slice);
+  arma_inline arma_warn_unused const oT&         at(const uword row, const uword col, const uword slice) const;
+  
+  arma_inline arma_warn_unused       oT& operator()(const uword row, const uword col);
+  arma_inline arma_warn_unused const oT& operator()(const uword row, const uword col) const;
 
-  arma_inline       oT&         at(const uword row, const uword col, const uword slice);
-  arma_inline const oT&         at(const uword row, const uword col, const uword slice) const;
-  
-  arma_inline       oT& operator()(const uword row, const uword col);
-  arma_inline const oT& operator()(const uword row, const uword col) const;
-
-  arma_inline       oT& operator()(const uword row, const uword col, const uword slice);
-  arma_inline const oT& operator()(const uword row, const uword col, const uword slice) const;
+  arma_inline arma_warn_unused       oT& operator()(const uword row, const uword col, const uword slice);
+  arma_inline arma_warn_unused const oT& operator()(const uword row, const uword col, const uword slice) const;
   
   
-  arma_cold inline field_injector<field> operator<<(const oT& val);
-  arma_cold inline field_injector<field> operator<<(const injector_end_of_row<>& x);
+  arma_inline arma_warn_unused       oT& front();
+  arma_inline arma_warn_unused const oT& front() const;
+  
+  arma_inline arma_warn_unused       oT& back();
+  arma_inline arma_warn_unused const oT& back() const;
+  
+  
+  arma_deprecated inline field_injector<field> operator<<(const oT& val);
+  arma_deprecated inline field_injector<field> operator<<(const injector_end_of_row<>& x);
   
   
   inline       subview_field<oT> row(const uword row_num);
@@ -198,11 +217,11 @@ class field
   inline arma_cold bool load(      std::istream& is,   const file_type type = auto_detect);
   
   
-  inline arma_cold bool quiet_save(const std::string   name, const file_type type = arma_binary) const;
-  inline arma_cold bool quiet_save(      std::ostream& os,   const file_type type = arma_binary) const;
+  arma_deprecated inline bool quiet_save(const std::string   name, const file_type type = arma_binary) const;
+  arma_deprecated inline bool quiet_save(      std::ostream& os,   const file_type type = arma_binary) const;
   
-  inline arma_cold bool quiet_load(const std::string   name, const file_type type = auto_detect);
-  inline arma_cold bool quiet_load(      std::istream& is,   const file_type type = auto_detect);
+  arma_deprecated inline bool quiet_load(const std::string   name, const file_type type = auto_detect);
+  arma_deprecated inline bool quiet_load(      std::istream& is,   const file_type type = auto_detect);
   
   
   // for container-like functionality
@@ -283,7 +302,7 @@ class field
   
   public:
   
-  #ifdef ARMA_EXTRA_FIELD_PROTO
+  #if defined(ARMA_EXTRA_FIELD_PROTO)
     #include ARMA_INCFILE_WRAP(ARMA_EXTRA_FIELD_PROTO)
   #endif
   };
