@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -26,62 +28,43 @@ normcdf_helper(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_ty
   {
   arma_extra_debug_sigprint();
   
-  #if !defined(ARMA_USE_CXX11)
+  typedef typename T1::elem_type eT;
+  
+  if(Proxy<T1>::use_at || Proxy<T2>::use_at || Proxy<T3>::use_at)
     {
-    arma_stop_logic_error("normcdf(): C++11 compiler required");
+    const quasi_unwrap<T1> UX(X_expr.get_ref());
+    const quasi_unwrap<T2> UM(M_expr.get_ref());
+    const quasi_unwrap<T3> US(S_expr.get_ref());
+    
+    normcdf_helper(out, UX.M, UM.M, US.M);
     
     return;
     }
-  #else
+  
+  const Proxy<T1> PX(X_expr.get_ref());
+  const Proxy<T2> PM(M_expr.get_ref());
+  const Proxy<T3> PS(S_expr.get_ref());
+  
+  arma_debug_check( ( (PX.get_n_rows() != PM.get_n_rows()) || (PX.get_n_cols() != PM.get_n_cols()) || (PM.get_n_rows() != PS.get_n_rows()) || (PM.get_n_cols() != PS.get_n_cols()) ), "normcdf(): size mismatch" );
+  
+  out.set_size(PX.get_n_rows(), PX.get_n_cols());
+  
+  eT* out_mem = out.memptr();
+  
+  const uword N = PX.get_n_elem();
+  
+  typename Proxy<T1>::ea_type X_ea = PX.get_ea();
+  typename Proxy<T2>::ea_type M_ea = PM.get_ea();
+  typename Proxy<T3>::ea_type S_ea = PS.get_ea();
+  
+  const bool use_mp = arma_config::openmp && mp_gate<eT,true>::eval(N);
+  
+  if(use_mp)
     {
-    typedef typename T1::elem_type eT;
-    
-    if(Proxy<T1>::use_at || Proxy<T2>::use_at || Proxy<T3>::use_at)
-      {
-      const quasi_unwrap<T1> UX(X_expr.get_ref());
-      const quasi_unwrap<T2> UM(M_expr.get_ref());
-      const quasi_unwrap<T3> US(S_expr.get_ref());
-      
-      normcdf_helper(out, UX.M, UM.M, US.M);
-      
-      return;
-      }
-    
-    const Proxy<T1> PX(X_expr.get_ref());
-    const Proxy<T2> PM(M_expr.get_ref());
-    const Proxy<T3> PS(S_expr.get_ref());
-    
-    arma_debug_check( ( (PX.get_n_rows() != PM.get_n_rows()) || (PX.get_n_cols() != PM.get_n_cols()) || (PM.get_n_rows() != PS.get_n_rows()) || (PM.get_n_cols() != PS.get_n_cols()) ), "normcdf(): size mismatch" );
-    
-    out.set_size(PX.get_n_rows(), PX.get_n_cols());
-    
-    eT* out_mem = out.memptr();
-    
-    const uword N = PX.get_n_elem();
-    
-    typename Proxy<T1>::ea_type X_ea = PX.get_ea();
-    typename Proxy<T2>::ea_type M_ea = PM.get_ea();
-    typename Proxy<T3>::ea_type S_ea = PS.get_ea();
-    
-    const bool use_mp = arma_config::cxx11 && arma_config::openmp && mp_gate<eT,true>::eval(N);
-    
-    if(use_mp)
-      {
-      #if defined(ARMA_USE_OPENMP)
-        {
-        const int n_threads = mp_thread_limit::get();
-        #pragma omp parallel for schedule(static) num_threads(n_threads)
-        for(uword i=0; i<N; ++i)
-          {
-          const eT tmp = (X_ea[i] - M_ea[i]) / (S_ea[i] * (-Datum<eT>::sqrt2));
-          
-          out_mem[i] = eT(0.5) * std::erfc(tmp);
-          }
-        }
-      #endif
-      }
-    else
+    #if defined(ARMA_USE_OPENMP)
       {
+      const int n_threads = mp_thread_limit::get();
+      #pragma omp parallel for schedule(static) num_threads(n_threads)
       for(uword i=0; i<N; ++i)
         {
         const eT tmp = (X_ea[i] - M_ea[i]) / (S_ea[i] * (-Datum<eT>::sqrt2));
@@ -89,8 +72,17 @@ normcdf_helper(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_ty
         out_mem[i] = eT(0.5) * std::erfc(tmp);
         }
       }
+    #endif
+    }
+  else
+    {
+    for(uword i=0; i<N; ++i)
+      {
+      const eT tmp = (X_ea[i] - M_ea[i]) / (S_ea[i] * (-Datum<eT>::sqrt2));
+      
+      out_mem[i] = eT(0.5) * std::erfc(tmp);
+      }
     }
-  #endif
   }
 
 
@@ -101,19 +93,9 @@ arma_warn_unused
 typename enable_if2< (is_real<eT>::value), eT >::result
 normcdf(const eT x)
   {
-  #if !defined(ARMA_USE_CXX11)
-    {
-    arma_stop_logic_error("normcdf(): C++11 compiler required");
-    
-    return eT(0);
-    }
-  #else
-    {
-    const eT out = eT(0.5) * std::erfc( x / (-Datum<eT>::sqrt2) );
-    
-    return out;
-    }
-  #endif
+  const eT out = eT(0.5) * std::erfc( x / (-Datum<eT>::sqrt2) );
+  
+  return out;
   }
 
 
@@ -124,21 +106,11 @@ arma_warn_unused
 typename enable_if2< (is_real<eT>::value), eT >::result
 normcdf(const eT x, const eT mu, const eT sigma)
   {
-  #if !defined(ARMA_USE_CXX11)
-    {
-    arma_stop_logic_error("normcdf(): C++11 compiler required");
-    
-    return eT(0);
-    }
-  #else
-    {
-    const eT tmp = (x - mu) / (sigma * (-Datum<eT>::sqrt2));
-    
-    const eT out = eT(0.5) * std::erfc(tmp);
-    
-    return out;
-    }
-  #endif
+  const eT tmp = (x - mu) / (sigma * (-Datum<eT>::sqrt2));
+  
+  const eT out = eT(0.5) * std::erfc(tmp);
+  
+  return out;
   }
 
 
